==> apache-kylin-3.0.1-source-release.zip: apache-kylin-3.0.1/tool/src/test/java/org/apache/kylin/tool/ClientEnvExtractorTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package org.apache.kylin.tool;

import org.apache.kylin.common.util.HBaseMetadataTestCase;
import org.junit.After;
import org.junit.Before;
import org.junit.Rule;
import org.junit.Test;
import org.junit.rules.TemporaryFolder;

import java.io.File;
import java.io.IOException;

public class ClientEnvExtractorTest extends HBaseMetadataTestCase {

    @Rule
    public TemporaryFolder folder = new TemporaryFolder();

    @Before
    public void setup() throws Exception {
        super.createTestMetadata();
    }

    @After
    public void after() throws Exception {
        super.cleanupTestMetadata();
    }

    @Test
    public void testNormal() throws IOException {
        File f = folder.newFolder("ClientEnvExtractorTest_testNormal");
        ClientEnvExtractor executor = new ClientEnvExtractor();
        executor.addShellOutput("pwd", f.getAbsolutePath(), "testNormal");
    }

    @Test(timeout = 5000)
    public void testTimeout() throws IOException {
        File f = folder.newFolder("ClientEnvExtractorTest_testTimeout");
        ClientEnvExtractor executor = new ClientEnvExtractor();
        executor.maxWaitSeconds = 2;
        executor.addShellOutput("sleep 1000", f.getAbsolutePath(), "testTimeout");
        executor.addShellOutput("pwd", f.getAbsolutePath(), "pwd");
    }

    @Test
    public void testError() throws IOException {
        File f = folder.newFolder("ClientEnvExtractorTest_testError");
        ClientEnvExtractor executor = new ClientEnvExtractor();
        executor.addShellOutput("CMD_NEVER_EXISTS", f.getAbsolutePath(), "testError");
    }
}

==> apache-kylin-3.1.3-source-release.zip: apache-kylin-3.1.3/tool/src/test/java/org/apache/kylin/tool/ClientEnvExtractorTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package org.apache.kylin.tool;

import org.apache.kylin.common.util.HBaseMetadataTestCase;
import org.apache.kylin.tool.extractor.ClientEnvExtractor;
import org.junit.After;
import org.junit.Before;
import org.junit.Rule;
import org.junit.Test;
import org.junit.rules.TemporaryFolder;

import java.io.File;
import java.io.IOException;

public class ClientEnvExtractorTest extends HBaseMetadataTestCase {

    @Rule
    public TemporaryFolder folder = new TemporaryFolder();

    @Before
    public void setup() throws Exception {
        super.createTestMetadata();
    }

    @After
    public void after() throws Exception {
        super.cleanupTestMetadata();
    }

    @Test
    public void testNormal() throws IOException {
        File f = folder.newFolder("ClientEnvExtractorTest_testNormal");
        ClientEnvExtractor executor = new ClientEnvExtractor();
        executor.addShellOutput("pwd", f.getAbsolutePath(), "testNormal");
    }

    @Test(timeout = 5000)
    public void testTimeout() throws IOException {
        File f = folder.newFolder("ClientEnvExtractorTest_testTimeout");
        ClientEnvExtractor executor = new ClientEnvExtractor();
        executor.maxWaitSeconds = 2;
        executor.addShellOutput("sleep 1000", f.getAbsolutePath(), "testTimeout");
    }

    @Test
    public void testError() throws IOException {
        File f = folder.newFolder("ClientEnvExtractorTest_testError");
        ClientEnvExtractor executor = new ClientEnvExtractor();
        executor.addShellOutput("CMD_NEVER_EXISTS", f.getAbsolutePath(), "testError");
    }
}
